/*
 * matrix.h
 *
 * Copyright (C) 1997 Fredrik Noring
 *
 * This file is subject to the terms and conditions of the GNU General Public
 * License.  See the file COPYING in the main directory of this archive
 * for more details.
 */

#define MATRIX_MAJOR 60

#define MATRIX_GET_SNDSTATUS   0    /* Sound status information */

#define MATRIX_SET_LTATTEN     1    /* Left channel output attenuation  */
#define MATRIX_SET_RTATTEN     2    /* Right channel output attenuation */
#define MATRIX_SET_LTGAIN      3    /* Left channel input gain          */
#define MATRIX_SET_RTGAIN      4    /* Right channel input gain         */

#define MATRIX_SET_ADDERIN     5    /* Adder mode (ADC/Matrix) */
#define MATRIX_SET_ADCINPUT    6    /* ADC input (Left/Right)  */

#define MATRIX_SET_MODE        7    /* Record and playback mode */

#define MATRIX_SET_PLAYTRACKS  8    /* Number of playback tracks */
#define MATRIX_SET_RECTRACKS   9    /* Number of record tracks   */

#define MATRIX_SET_MONTRACK   10    /* Internal speaker monitor track */

#define MATRIX_SET_TRISTATE   11    /* DSP Tristate/Enable */

/* General Purpose I/O pins on the DSP connector */
#define MATRIX_GPIO_DIR       12
#define MATRIX_GPIO_READ      13
#define MATRIX_GPIO_WRITE     14

/* Matrix source connections */
#define MATRIX_SET_ADC        15   /* Microphone/PSG */
#define MATRIX_SET_EXTINP     16   /* External Input */
#define MATRIX_SET_DSPXMIT    17   /* DSP Transmit   */
#define MATRIX_SET_DMAPLAY    18   /* DMA Playback   */

#define MATRIX_SET_CLK_SRC    19   /* Clock source device */
#define MATRIX_SET_PRESCALE   20

#define MATRIX_INIT_DMA       21   /* Init matrix DMA */
#define MATRIX_EXIT_DMA       22   /* Turn off matrix DMA */

#define MATRIX_GET_WRITTEN    23   /* Get amount of data written to dma buffer */
#define MATRIX_TEST_EXTERNAL  24   /* Check if external clock is installed */

/* Modes */

/* DSP tristate settings */
#define MATRIX_TRISTATE_DSP    0x0
#define MATRIX_ENABLE_DSPXMIT  0x1
#define MATRIX_ENABLE_DSPREC   0x2

/* Adder mode */
#define MATRIX_ADC             0x1
#define MATRIX_MATRIX          0x2

/* ADC input */
#define MATRIX_NOINPUT         0x0
#define MATRIX_LEFT            0x1
#define MATRIX_RIGHT           0x2

/* Matrix destination conections */
#define MATRIX_DAC             0x8   /* Headphone or internal speaker */
#define MATRIX_EXTOUT          0x4   /* External out                  */
#define MATRIX_DSPRECV         0x2   /* DSP Receive                   */
#define MATRIX_DMAREC          0x1   /* DMA Record                    */

/* Source clock devices */
#define	MATRIX_CLK_SRC_25MHZ   0
#define	MATRIX_CLK_SRC_EXT     1
#define	MATRIX_CLK_SRC_32MHZ   2

/* Playback and record modes */
#define MATRIX_MODE_8STEREO    0
#define MATRIX_MODE_16STEREO   1
#define MATRIX_MODE_8MONO      2

/* Clock prescale modes */
#define MATRIX_CLK50K          1
#define MATRIX_CLK33K          2
#define MATRIX_CLK25K          3
#define MATRIX_CLK20K          4
#define MATRIX_CLK16K          5
#define MATRIX_CLK12K          7
#define MATRIX_CLK10K          9
#define MATRIX_CLK8K          11
